<?php


namespace Ardent\PicnicApi;


use GuzzleHttp\Client;
use GuzzleHttp\RequestOptions;

class ClientBuilder
{
    const DEFAULT_COUNTRY_CODE = "NL";
    const DEFAULT_API_VERSION = "15";

    private string $username;
    private string $password;

    /**
     * ClientBuilder constructor.
     */
    public function __construct(string $username, string $password)
    {
        $this->username = $username;
        $this->password = $password;
    }

    public function getClient(): Client
    {
        return new Client([
            'base_uri' => $this->getBaseUri(),
            'headers' => $this->getHeaders(),
        ]);
    }

    private function authenticate(): string
    {
        $client = new Client([
            'base_uri' => $this->getBaseUri(),
        ]);
        $data = [
            'key' => $this->username, // username
            'secret' => md5($this->password), // password
            'client_id' => 1,
        ];
        $result = $client->post('user/login', [
            RequestOptions::JSON => $data,
        ]);
//        $body = json_decode($result->getBody()->getContents(), true);
//        $userId = $body['user_id'];
//        $meta = json_decode(base64_decode($result->getHeader('picnic-meta-info')[0]))

        return $result->getHeader('x-picnic-auth')[0];
    }

    private function getBaseUri(): string
    {
        return sprintf('https://storefront-prod.%s.picnicinternational.com/api/%s/',
            self::DEFAULT_COUNTRY_CODE,
            self::DEFAULT_API_VERSION
        );
    }

    private function getHeaders(): array
    {
        return [
            'x-picnic-auth' => $this->authenticate(),
        ];
    }
}